package com.ruoyi.web.modules.trading.service;

import java.util.List;
import com.ruoyi.web.modules.trading.domain.BizSupplier;

/**
 * 供应商服务
 */
public interface IBizSupplierService
{
    BizSupplier selectBizSupplierById(Long id);

    List<BizSupplier> selectBizSupplierList(BizSupplier query);

    int insertBizSupplier(BizSupplier row);

    int updateBizSupplier(BizSupplier row);

    int deleteBizSupplierByIds(Long[] ids, String updateBy);

    int assignAccount(Long id, String operator);
}
